/*
*==============================================================================
*
*  Name   :  RMSNavigFuncs.js
*
*  Version:  1.0
*
*  Purpose:  JavaScript auxliary functions supporting navigation within 
*            the RAMSES Objects HTML Documentation web pages.
*
*==============================================================================
* Implementation and Revisions:
*------------------------------------------------------------------------------
* Author  Date      Description
* ------  ----      -----------
* dg      15/08/06  First implementation based on ROHD_OpenFile.bash
*                   - Added delayed call to ScrollUp in HighlightObjectDefinition
* dg      14/09/06  HighlightObjectDefinition now adapted to use of styles
*
*==============================================================================
*/

  function GetSelection() {
    if        (window.getSelection)   { return window.getSelection()
    } else if (document.getSelection) { return document.getSelection()
    } else if (document.selection)    { return document.selection.createRange().text
    } else return ""
  }

  function PageUnloadHandler(){
    ShowIdleButton();
    return true
  }

  function GoToSearchPage( srchPageURL ) { 
    var s = GetSelection(); 
    document.location = srchPageURL + (s=="" ? "" : "#"+s); 
    return true
  }

  function ShowIdleButton() { document.images["search_button"].src = "images/SearchButton.png";  return true }
  
  function ShowUpButton()   { document.images["search_button"].src = "images/SearchButtonU.png"; return true }

  function ShowDownButton() { document.images["search_button"].src = "images/SearchButtonD.png"; return true }
  
  function MouseDownHandler( srchPageURL ) {
    ShowDownButton(); 
    GoToSearchPage( srchPageURL ); 
    return true
  }

  function MouseUpHandler()  {
    ShowUpButton(); 
    return true 
  }

  function KeyPressHandler(e, curNavigItem, srchPageURL) {
    if ( curNavigItem == "Search" ) { return false }
    if ( e.keyCode ) {var keycode = e.keyCode} else {var keycode = e.which}
    if ( keycode == 13 ) {ShowDownButton(); GoToSearchPage( srchPageURL )}
    return true;
  }

  function ScrollUp( numPixels ) {
    //alert('ScrollUp');
    window.scrollBy( 0, -numPixels );
  }
  
  function HighlightObjectDefinition( curNavigItem ) {
    if ( curNavigItem == "Search" ) { return false }
    var srchAddr = location.hash.substring(1,512);
    if (!srchAddr || !document.body || typeof(document.body.innerHTML) == "undefined") { return false }
    var isExplorer = navigator.appName.toUpperCase().match(/EXPLORER/) != null;
    var isMacintosh = navigator.appVersion.toUpperCase().match(/MAC/) != null;
    if (isExplorer && isMacintosh) {
      // There is a problem with large documents (e.g., QuickRefs) 
      // when attempting to change innerHTML, so don't do anything.
      //alert('isExplorer && isMacintosh');
      return false
    } 
    var bodyText = document.body.innerHTML;
    if (isExplorer) {
      var srchStr = 'class=obj name=' + unescape(srchAddr);
    } else {
      var srchStr = 'name="' + unescape(srchAddr) + '" class="obj"';
    }
    //var i = bodyText.indexOf( "SampleMods.html", 0); alert(bodyText.substring(i-200,i+200));
    var i = bodyText.indexOf( srchStr, 0); if (i < 0) { return false }
    var newText = bodyText.substring(0,i);
    newText = newText + 'class="hlt" name="' + unescape(srchAddr) +'"';
    newText = newText + bodyText.substring(i+srchStr.length, bodyText.length);
    //alert(newText.substring(i-200,i+200));
    document.body.innerHTML = newText;
    setTimeout('ScrollUp( 30 )', 10); // scroll after 10 milliseconds
    return true
  }
